@@ -1,6 +1,6 @@
 #' Normalization of a bca mass function
 #'
-#' It may occur that the result of the combination of two mass functions with Dempater'Rule of combination contains a non-zero mass allocated to the empty set. The function \code{nzdsr} normalizes the result of function \code{dsrwon} by dividing the mass value of the non-empty subsets by 1 minus the mass of the empty set. 
+#' It may occur that the result of the combination of two mass functions with Dempster's Rule of combination contains a non-zero mass allocated to the empty set. The function \code{nzdsr} normalizes the result of function \code{dsrwon} by dividing the mass value of the non-empty subsets by 1 minus the mass of the empty set. 
 #' @param x A mass function, i.e. a list of class bcaspec..
 #' @return The normalized bca mass function.
 #' @author Claude Boivin, Stat.ASSQ
@@ -33,6 +33,7 @@ nzdsr<-function(x) {
   if (is.null(x$I12)) {
     nc <- ncol(x$tt)
     frame <- bca(matrix(rep(1, nc), nrow=1), m=1)
+    frame$infovaluenames <- x$infovaluenames
     x <- dsrwon(x,frame)
   }
   w12<-cbind(x$spec[,2], x$tt)
