@@ -11,7 +11,12 @@ test_that("dsrwon", {
   x2 <- bca(f=matrix(c(0,1,1,1,1,1,0,1,1,1,1,1),nrow=3, byrow = TRUE), m=c(0.2,0.5, 0.3), cnames =c("a", "b", "c","d"),  infovarnames = "x2", varnb = 1)
   expect_error(dsrwon(x = x2, y = y1) , "Nb of elements of frame x and frame y not equal.")
   #
-  # T3 warning message when evidence is completely contradictory
+  ## T3 Value names of the two frames must be the same and in the same order.
+  z1 <- bca(f= matrix(c(1,0,0,1,1,1), ncol=2, byrow=TRUE), m= c(0.99, 0.01, 0), cnames =c("M", "T"), infovarnames = "Diagnosis1", varnb = 1)
+  z2 <- bca(f= matrix(c(1,0, 0,1, 1,1), ncol=2, byrow=TRUE), m= c(0.01, 0.99, 0), cnames =c("C", "T"), infovarnames = "Diagnosis2", varnb = 2)
+  expect_error(dsrwon(x = z1, y = z2) , "Value names of the two frames differ. Check value names of variables as well as their position.")
+  #
+    # T4 warning message when evidence is completely contradictory
   cnames <- c("yes","no")
   f1<- t(matrix(c(1,0,1,1),ncol=2))
   m1<- c(1,0)
