@@ -1,4 +1,6 @@
 # Tests "plautrans" function
+context("Plausibility transformation")
+library(dst)
 test_that("plautrans", {
   # T1 x and y must be of class bcaspec. 
   x1 <- list(f=matrix(c(1,0,0,1,1,1),nrow=2, byrow = TRUE), m=c(0.6, 0.4),  cnames = c("a", "b", "c"),  infovarnames = "x1", varnb = 1)
